@@ -2,7 +2,7 @@ package Nephia;
 use strict;
 use warnings;
 use File::Spec;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub import {
     my ($class, %opts) = @_;
@@ -203,6 +203,22 @@ Example:
 
 "/chilapp" connect to "MyApp::Child".
 
+=head2 Using Cookie
+
+If you want to set cookie, use "set_cookie" command.
+
+  path '/somepath' => sub {
+      set_cookie cookiename => 'cookievalue';
+      return +{ ... };
+  };
+
+And, getting a cookie value, use "cookie" command.
+
+  path '/anypath' => sub {
+      my $cookie_value = cookie 'cookiename';
+      return +{ ... };
+  };
+
 =head1 USING CONFIG
 
 First, see app.psgi that generated by C<nephia-setup>.
@@ -318,6 +334,14 @@ Return config as hashref.
 
 Return the absolute path to root of application.
 
+=head2 cookie $cookie_name
+
+Get specified cookie value.
+
+=head2 set_cookie $cookie_name => $cookie_value
+
+Set value into specified cookie.
+
 =head2 nephia_plugins @plugins
 
 Load specified Nephia plugins.
